.. Heisenberg - ProjectQ -Cirq - Extension documentation master file, created by
   sphinx-quickstart on Tue Jul 10 13:16:32 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Heisenberg - ProjectQ -Cirq - Extension's documentation!
===================================================================


.. toctree::
   :maxdepth: 4
   :caption: Contents:

   source/introduction
   source/Examples
   source/CIRQ
   source/Decompose


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
